@@ -28,8 +28,9 @@ class Templates(Enum):
     Enum of templates to be used in the app.
     Values must match the file name in the templates directory.
     """
-    DEFAULT = 'default'
-    MINIMAL = 'minimal'
+    DEFAULT = 'default'  # Default template multipage app.
+    MINIMAL = 'minimal'  # Minial template for a simple app.
+    HEROKU = 'heroku'  # Includes Heroku files.
 
 
 def _convert_to_template_or_error(value) -> Templates:
@@ -37,7 +38,7 @@ def _convert_to_template_or_error(value) -> Templates:
     Convert the string passed to the init command to a template.
     """
     try:
-        return Templates(value)
+        return Templates(value.lower())
     except ValueError:
         exit(
             f'dash-tools: init: Template "{value}" is not valid. Aborting.')
